@@ -293,16 +293,17 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
     # ensure yarn installs all build tools
-    yarn_cache=os.getenv('PWD','') + '.yarn_cache/'
+    yarn_cache=os.getenv('PWD','') + '/.yarn_cache/'
     local('mkdir -p .yarn_cache/')
+    local('yarn config set cache-folder %s' % yarn_cache)
     with lcd(installPath):
         local("pwd")
-        local('yarn --production=false --no-progress --non-interactive --cache-folder %s install' % yarn_cache)
+        local('yarn --production=false --no-progress --non-interactive --cache-folder install')
 
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('yarn build %s %s --cache-folder %s ' % (options, ngApp, yarn_cache))
+            local('yarn build %s %s ' % (options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
